bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 33. Aventiure
___________________________________________________
| ### Also der chvene Danchwart vnder di tver getrat ### daz Eceln gesinde er hoher wichen bat ### mit blvte was bervnnen allez sin gewant ### ein vil starchez waffen daz trvg er bloz an siner hant ### Vil lvt rief do Danchwart zv dem degene ### ir sitzet al ce lange brvder Hagene ### iv vnde got von himele chlag ich vnser not ### ritter vnde knehte sint in den herbergen tot
###### 1950 | ### Er rief im hin engegene wer hat daz getan ### daz het der herre Blodelin vnde sine man ### ovch hat ers ser engolten daz wil ich iv sagen ### ich han mit minen handen im sin hovbet abe geslagen
| ### Daz ist ein schade chleine sprach aber Hagene ### da man saget mære von einem degene ### ob er <von> rechen henden verlivset sinen lip ### in svln deste ringer chlagen wætlichiv wip
###### 1952 | ### Nv saget mir brvder Danchwart wi sit ir so rot ### ich wene ir von vinden lidet groze not ### ist er inder ime lande derz iv hat getan ### in en nert der vbel tivfel ez mvz im an sin leben gan
###### 1953 | ### Dv sihest mich wol gesvnden min wat ist blvtes naz ### von anderr manne wnden ist mir geschehen daz ### der ich also manegen hivte han erslagen ### ob iches swern solde ine chvndiz nimmer gesagen
| ### Er sprach brvder Danchwart <so> hvetet vns der tveer ### vnde lat der Hivnen einen chomen niht der fver ### ich wil reden mit den recken als vns des twinget not ### vnser ingesinde lit vor in vnverdienet tot [389b]
###### 1955 | ### Sol ich sin chamerære sprach der chvene man ### also richen chvenegen ich gedienen chan ### so pflige ich der stiegen nach den eren min ### den Criemhilde degenen chvnde leider niht gesin
###### 1956 | ### Mich nimt des michel wnder sprach aber Hagene ### waz nv hinne rvnen di Hivnen degene ### si wæn liht des enbæren der an der tvr da stat ### vnt div hovemære gesaget den Bvergonden hat
| ### Ich han vernomen lange von Criemhilde sagen ### daz si ir herceleide wold niht vertragen ### nv trinchen wir di minne vnde gelten skveneges win ### der ivnge vogt der Hivnen der mvz der erste sin
###### 1958 | ### Do slvch daz chint Ortlieben Hagen der helt gvt ### daz im gegen der hende ame swerte vloz daz blvt ### vnt daz dem chvenege daz hovbet spranch in di shoz ### do hvb sich vnder degenen ein mort vil grimmech vnde groz
###### 1959 | ### Dar nach slvg er den magtzogen einen swinden slach ### mit beiden sinen henden der des chindes pflach ### daz im daz hovbet schiere vor dem thisshe nider lach ### ez was ein iamerliches lon daz er dem magtzogen wach
| ### Er sach vor Eceln thisse einen spilman ### Hagen in sinem zorne gahen dar began ### er slvch <im> vf der videlen ab di zeswen hant ### daz habe dir ce botschepfte in der Bvrgonden lant
###### 1961 | ### So we mir miner hende sprach Werbel der spilman ### her Hagen von Tronege waz het ich iv getan ### ich chom vf groze triwe in iwerr herren lant ### wi chlinge ich nv di done sit ich verlorn han di hant
###### 1962 | ### Hagen geahtet ringe gevidelte er nimmer mer ### do frvmt er in dem hvse div mortgrimmen ser ### an den Eceln rechen der er so vil erslvch ### do braht er in dem hvse livtes ce tode genvch
| ### Volker der vil snelle von dem thisse spranch ### sin videlboge im lvt [390a] an siner hende erchlanch ### do videlte vngefvge Gvntheres spilman ### hey waz er im ce viende der chvenen Hivnen gewan
###### 1964 | ### Ovch sprvngen von den thissen di drie chvenege her ### si woldenz gerne scheiden ê daz shaden geshæhe mer ### sine <mohtenz> mit ir sinnen do niht vnderstan ### do Volker vnde Hagene so sere weten began
###### 1965 | ### Do sach der vogt von Rine vngescheiden <den> strit ### do slvch der fvrste selbe vil manige wnden wit ### dvrch di liehten ringe den vianden sin ### er was ein helt cen handen daz tet er groezliche schin
| ### Do chom ovch zv dem strite der starche Gernot ### ia frvmte er der Hivnen vil manegen helt tot ### mit einem sharpfen swerte daz gab im Rvedeger ### den Eceln rechen tet er div groezlichen ser
###### 1967 | ### Der ivnge svn vrovn Vten zv dem strite spranch ### sin waffen herlichen dvrch di helm erchlanch ### den Eceln recken vzer Hivnen lant ### da tet vil michel wnder des chvenen Giselheres hant
###### 1968 | ### Swi frvm si alle wæren di chvnege vnd alle ir man ### doch sach man vor in allen Giselheren stan ### gegen den vianden er was ein helt gvt ### er frvmt da mit wnden vil manegen vallen in daz plvt
| ### Ovch werten sich vil sere di Eceln man ### do sach man di geste hohwende stan ### mit den vil liehten swerten dvrh des chveneges sal ### do horte man allenthalben von wffe grozen schal
###### 1970 | ### Do wolden di dar vz zir frivnde sin dar in ### di namen an den tvernen vil chleinen gewin ### do wæren di dar inne vil gerne fver den sal ### Danchwart liez ir deheinen di stiegen vf vnde ovch ce tal
###### 1971 | ### Des hvb sich vor dem tvrne vil starcher gedranch ### vnde ovch von den swerten grozer helme chlanch ### des chom der chvene Danchwart in eine groze not ### daz besorgte sin brvder als im sin triwe daz gebot [390b]
###### 1972 | ### Vil lvte rief do Hagene Voelkeren an ### seht ir dort geselle minen brvder stan ### vor hivnisschen recken vnder starchen slegen ### vrivnt nert mir den brvder ê wir vliesen den degen
###### 1973 | ### Daz tvn ich sicherlichen sprach der spilman ### er begonde videlende dvrch den palas gan ### ein hertez swert im ofte an siner hende erchlanch ### di recken von dem Rine im sageten grozlichen danch
| ### Volker der chvene zv Danchwarten sprach ### ir habt erlitten hivte vil grozen vngemach ### mich bat iwer brvder dvrch helfe zu ziv gan ### welt ir nv sin dar vze so wil ich innerthalben stan
###### 1975 | ### Danchwart der snelle stvnt vzerthalp der tver ### er werte in ir stiege swaz ir chom darfver ### des horte man waffen hellen den helden an der hant ### sam tet ovch innerthalben Volker von Bvrgonden lant
###### 1976 | ### Der chvene videlære rief veber di menege ### der sal ist wol beslozen min vrivnt her Hagene ### ia ist also verschranchet div Eceln tver ### von zweir helde handen den gent wol tvsent rigel fver
| ### Do von Tronege Hagene di tver sah so behvt ### den schilt warf do ce rvke der mære helt gvt ### do begond er erste rêchen daz im was getan ### do heten sine viande cem lebene deheiner slahte wan
###### 1978 | ### Do der vogt von Rine reht daz ersach ### daz Hagen der starche so manegen helm brach ### der chvenech der Amelvnge spranch vf eine banch ### er sprach hie shenchet Hagene daz aller wirsiste tranch
| ### Der wirt het groze sorge als im do daz gezam ### waz man im lieber vrivnde vor sinen ovgen nam ### wande er vor sinen vinden vil chvme da genas ### er saz vil angestlichen was half in daz er kvenech was
###### 1980 | ### Criemhilt div riche rief Dieterichen an ### nv hilf mir ritter edele mit dem leben dan ### dvrch aller fversten [391a] tvgende vzer Amelvnge lant ### wand erreichet mich Hagene ich han den tot an der hant
###### 1981 | ### Wi sol ich iv nv gehelffen sprach her Dieterich ### edeliv chvneginne nv sorge ich vmbe mich ### ez sint so sere erzvernet di Gvntheres man ### daz ich an disen ziten gefriden niemen chan
| ### Neina herre Dieterich vil edel ritter gvt ### laza hivte schinen den tvgentlichen mvt ### daz dv mir helfest hinnen oder ich belibe tot ### der sorge gie Criemhilde vil harte groezliche not
###### 1983 | ### Daz wil versvchen ob ich iv gehelfen chan ### wande ich in manegen ziten nie gesehen han ### so bitterlich erzvernet so manegen ritter gvt ### ia sah er dvrch di helme von swerten springen daz plvt
###### 1984 | ### Mit krapf begonde rvfen der degen vz erchorn ### daz sin stimme erlvte alsam ein wisentes horn ### vnt daz div bvrch vil wite von siner crapft erdoz ### div sterche Dieteriches was vnmæzliche groz
| ### Do gehorte Gventher rvffen disen man ### in dem herten stvrme losen er began ### er sprach Dieteriches stimme ist in mine ore chomen ### ich wæne im vnser degene im haben etwæn hi benomen
###### 1986 | ### Ich sih in vf dem thisse er winchet mit der hant ### ir frivnt vnde mage von Bvergonden lant ### gehabt vf des strites lat hoeren vnde sehen ### waz hi dem degene von minen mannen si geschehen
###### 1987 | ### Do der kvenech Gventher bat vnde ovch gebot ### si habten vf mit swerten in des strites not ### daz was gewalt vil grozer daz da niemen slvch ### ia vragete den von Berne der mære schiere genvch
| ### Er sprach vil edel Dieterich waz ist iv hi getan ### von den minen vrivnden willen ich des han ### bvze vnde svne der bin ich iv bereit ### swaz iv iemen tæte daz wær mir innechlichen leit
###### 1989 | ### Do sprach der herre Dieterich mir ist niht getan ### lat mich vz dem hvse mit iwerem vride gan ### <von> diesem herten strite mit dem gesinde min ### daz wil ich sicherlichen immer dienende sin
###### 1990 | ### Wi vliehet ir so schiere sprach do Wolfrat ### ia hat der videlære di tver ni so verspart ### wir entsliezen so wite daz wir dar fver gan ### nv swiget sprach her Dieterich ir habet den tivel getan
| ### Do sprach der kvenech Gventher erlovben ich iv wil ### fvret v^ze dem hvse lvecel oder vil ### ane mine vinde di svln hi bestan ### si hant mir hi cen Hivnen so rehte leide getan
###### 1992 | ### Do er daz gehorte vnder arme er besloz ### di edeln kveneginne der sorge div was groz ### do fvrt er anderthalben Eceln mit im dan ### ovch mit Dieteriche sehs hvndert wætlicher man
###### 1993 | ### Do sprach der margrave der edel Rvedger ### sol aber vzem hvse iemen chomen mer ### di iv doch gerne dienen daz lazet vns vernemen ### so sol ovch vride stæter den gvten vienden gezemen
| ### Des antwrte Giselher von Bvrgonden lant ### vride vnde svne si iv von vns bechant ### sit ir sit triwen stæte ir vnde iwer man ### ir svlt vnangestlichen mit iwern vrivnden hinnen gan
###### 1995 | ### Do Rvedeger der herre gervmete den sal ### fvnfhvndert oder mere im volgeten veber al ### der von Bæchelaren vrivnt vnde siner man ### von dem chvenege Rvedeger schaden grozen sit gewan
###### 1996 | ### Do sach ein Hivnen recke Eceln gan ### bi Dieteriche nahen genôzen wold er sin han ### dem gap der videlære einen solhen slach ### daz im vor Eceln fvzzen daz hovbet schiere gelach
| ### Do der wirt des landes chom fver daz hvs gegan ### do chert er sich hin widere vnde sach Volkeren an ### owe mir dirre geste dice ist ein grimmigiv [392a] not ### daz alle mine recken svln vor in <wesen> tot
###### 1998 | ### Ach we der hohgezite sprach der chvenech her ### da vihtet einer inne der heizet Voelker ### als ein eber wilde vnde ist ein spilman ### ich danches minem heile daz ich dem tivel entran
###### 1999 | ### Sine leiche lvtent vbele sine zvege di sint rot ### ia vellent sine doene vil manigen helt tot ### ine weiz niht waz vns wize der selbe spilman ### wand ich gast ni deheinen so rehte leiden gewan
| ### Si heten di si wolden lazen fver den sal ### do hvb sich innerthalben ein grozlicher schal ### di geste sere rachen daz in ê geschach ### Volker der vil chvene hey waz er helme cerbrach
###### 2001 | ### Sich cherte gegen dem schalle gventher der kvenech her ### hoert ir doene Hagene di dort Volker ### videlt mit den Hivnen swer zv dem tvrn gat ### ez ist ein rôter anstrich den er ce dem videlbogen hat
###### 2002 | ### Mich riwet ane maze so sprach Hagene ### daz ich ie gesaz in dem hvse vor dem degene ### ich was sin geselle vnde ovch er der min ### vnd chome wir immer wider heim daz svln wir noch mit triwen sin
| ### Nv schowe kvenech here Volker ist dir holt ### er dienet vlizechliche din silber vnt din golt ### sin videlboge im snidet dvrch den herten stal ### er brichet vf den helmen div liehte schinenden mal
###### 2004 | ### Ine gesach nie videlære so herlichen stan ### als der degen Volker hivte hat getan ### di sinen leiche hellent dvrch helme vnd rant ### ia sol er riten gutiv ross vnde tragen herliche gewant
###### 2005 | ### Swaz der Hivnen mage in dem sal was genesen ### der enwas nv deheiner dar inne me genesen ### des was der schal geswiftet daz niemen mit in streit ### div swert von handen legeten di chvenen recken gemeit [392b]

<<< Übersicht <<< vorige Seite nächste Seite >>>